# pyvizbee
[![pytest](https://github.com/ffreemt/vizbee/actions/workflows/routine-tests.yml/badge.svg)](https://github.com/ffreemt/vizbee/actions)[![python](https://img.shields.io/static/v1?label=python+&message=3.8%2B&color=blue)](https://www.python.org/downloads/)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)[![PyPI version](https://badge.fury.io/py/pyvizbee.svg)](https://badge.fury.io/py/pyvizbee)

a dualtext aligner based on holoviz panel, currently for English and Chinese texts only

## Python version
Python 3.8 only, best with python 3.8.3 or 3.8.5

## Install it

```shell
pip install pyvizbee
python -m pyvizbee

```
#### Extra
Plotting is optinal and can be installed with
```shell
pip install pyvizbee[plot]
```
or simply install the required packages (holoviews,
plotly, seaborn), e.g. `pip install holoviews
plotly seaborn`

## Use it
```shell
python -m pyvizbee
```
